# Ranked Optimized: 1.2.1 for 1.21.11
**A smaller update compared to 1.2.0, but far better performance.**
For this version, we zoomed out and focused on larger-scale tweaks than small-config changes.
***Quick Highlights:***
- **Low- & Mid-End Systems:** **~170%-200%** average FPS, **~200%-250%** 1% low FPS, **~400%+** 0.1% low FPS, all compared to `1.2.0`
- **High-End Systems:** Slight performance increase (around 120% compared to `1.2.0` on all ends, I wouldn't say more - benchmarks in this were too variable)
***Noticeable Changes:***
- removed mod [RRLS/Remove Reloading Screen](<https://modrinth.com/mod/rrls>)
- default render distance: `12` -> `6` chunks
- BactroMod fire offset: `-100` (invisible) -> `-42` (barely visible)
- mod **[Disable Lighting](<https://modrinth.com/mod/disable-lighting>)** removed, hence **full bright is now off by default.** Check #"[1.2.1/1.2.0] Fullbright ON/OFF" for more info.
- mod **[Iris Shaders](<https://modrinth.com/mod/iris>)** and its shader packs removed
- mod **[Flashback](<https://modrinth.com/mod/flashback>)** removed
***Full Changes:***
- mipmap levels: 4x -> 2x
- Entity Culling: skip culling for minecraft:player
- added Better Block Entities: sign text distance 16 -> 32, rest default
- removed RRLS (Remove Reloading Screen) + its config
- tooltip delay: 500ms -> 300ms
- default render distance: 12 -> 6 chunks
- weather effect radius: 10 -> 5
- BactroMod fire offset: -100 (invisible) -> -42 (barely visible)
- ModernFix mixin.perf.deduplicate_climate_parameters: false -> true
- removed mod Disable Lighting
- Iris and its shaderpacks removed entirely (huge performance impact for no reason)
- Flashback removed entirely (medium performance impact for no reason)
Developer information
Projects on Modrinth are automatically available through a Maven repository for use with JVM build tools such as Gradle.
maven { name = "Modrinth"; url = "https://api.modrinth.com/maven" }